@@ -3,6 +3,7 @@ import os
 import subprocess
 import urllib
 import shutil
+import logging
 
 from zc.buildout import UserError
 import zc.recipe.egg
@@ -122,6 +123,7 @@ application = django.core.handlers.wsgi.WSGIHandler()
 
 class Recipe(object):
     def __init__(self, buildout, name, options):
+        self.log = logging.getLogger(name)
         self.egg = zc.recipe.egg.Egg(buildout, options['recipe'], options)
 
         self.buildout, self.name, self.options = buildout, name, options
@@ -136,7 +138,6 @@ class Recipe(object):
         options.setdefault(
             'media_root', 
             "os.path.join(os.path.dirname(__file__), 'media')")
-        options.setdefault('secret', self.generate_secret())
         # set this so the rest of the recipe can expect it to be there
         options.setdefault('pythonpath', '')
 
@@ -206,7 +207,7 @@ class Recipe(object):
             if not os.path.exists(project_dir):
                 self.create_project(project_dir)
             else:
-                print 'Skipping creating of project: %(project)s since it exists' % self.options
+                self.log.info('Skipping creating of project: %(project)s since it exists' % self.options)
 
         return location
 
@@ -218,17 +219,18 @@ class Recipe(object):
             self.version_to_download_suffix(version))
         if not install_from_cache:
             if os.path.exists(download_location):
-                if self.command('svn up %s' % download_location):
+                if self.svn_update(download_location, version):
                     raise UserError(
                         "Failed to update Django; %s. "
                         "Please check your internet connection." % (
                             download_location))
             else:
+                self.log.info("Checking out Django from svn: %s" % svn_url)
                 if self.command('svn co %s %s' % (svn_url, download_location)):
                     raise UserError("Failed to checkout Django. "
                                     "Please check your internet connection.")
         else:
-            print "Installing Django from cache: " + download_location
+            self.log.info("Installing Django from cache: " + download_location)
 
         shutil.copytree(download_location, location)
 
@@ -249,8 +251,8 @@ class Recipe(object):
         # Only download when we don't yet have an archive
         if not os.path.exists(tarball):
             download_url = 'http://www.djangoproject.com/download/%s/tarball/'
+            self.log.info("Downloading Django from: %s" % download_url)
             urllib.urlretrieve(download_url % version, tarball)
-
         return tarball
 
     def create_manage_script(self, extra_paths, ws):
@@ -284,21 +286,24 @@ class Recipe(object):
     def create_project(self, project_dir):
         os.makedirs(project_dir)
 
+        template_vars = {'secret': self.generate_secret()}
+        template_vars.update(self.options)
+
         self.create_file(
             os.path.join(project_dir, 'development.py'),
-            development_settings, self.options)
+            development_settings, template_vars)
 
         self.create_file(
             os.path.join(project_dir, 'production.py'),
-            production_settings, self.options)
+            production_settings, template_vars)
 
         self.create_file(
             os.path.join(project_dir, 'urls.py'),
-            urls_template, self.options)
+            urls_template, template_vars)
 
         self.create_file(
             os.path.join(project_dir, 'settings.py'),
-            settings_template, self.options)
+            settings_template, template_vars)
 
         # Create the media and templates directories for our
         # project
@@ -318,6 +323,8 @@ class Recipe(object):
         f = open(script_name, 'w')
         o = {'extra_paths': repr(extra_paths)}
         o.update(self.options)
+        if self.options.get('projectegg'):
+            o['project'] = self.options.get('projectegg')
         f.write(wsgi_template % o)
         f.close()
 
@@ -339,22 +346,24 @@ class Recipe(object):
             return 'svn'
         return [p for p in version.split('/') if p][-1]
 
+    def svn_update(self, path, version):
+        command = 'svn up'
+        if '@' in self.options['version']:
+            command += ' -r ' + version.split('@')[-1]
+        self.log.info("Updating Django from svn")
+        return self.command(command, cwd=path)
+
     def update(self):
         if not self.install_from_cache and \
                 self.is_svn_url(self.options['version']):
+            self.svn_update(self.options['location'], self.options['version'])
 
-            command = 'svn up'
-            if '@' in self.options['version']:
-                command += ' -r ' + self.options['version'].split('@')[-1]
-            subprocess.call(command, shell=True, 
-                            cwd=self.options['location'])
-
-    def command(self, cmd):
+    def command(self, cmd, **kwargs):
         output = subprocess.PIPE
         if self.buildout['buildout'].get('verbosity'):
             output = None
         command = subprocess.Popen(
-            cmd, shell=True, stdout=output)
+            cmd, shell=True, stdout=output, **kwargs)
         return command.wait()
 
     def create_file(self, file, template, options):
