@@ -52,6 +52,26 @@ class TestRecipe(unittest.TestCase):
         # Remove our test dir
         shutil.rmtree(self.buildout_dir)
 
+    def test_consistent_options(self):
+        # Buildout is pretty clever in detecting changing options. If
+        # the recipe modifies it's options during initialisation it
+        # will store this to determine wheter it needs to update or do
+        # a uninstall & install. We need to make sure that we normally
+        # do not trigger this. That means running the recipe with the
+        # same options should give us the same results.
+        self.assertEqual(*[
+                Recipe({'buildout': {'eggs-directory': self.eggs_dir,
+                                     'develop-eggs-directory': self.develop_eggs_dir,
+                                     'python': 'python-version',
+                                     'bin-directory': self.bin_dir,
+                                     'parts-directory': self.parts_dir,
+                                     'directory': self.buildout_dir,
+                                     },
+                        'python-version': {'executable': sys.executable}}, 
+                       'django', 
+                       {'recipe': 'djangorecipe',
+                        'version': 'trunk'}).options.copy() for i in range(2)])
+
     def test_svn_url(self):
         # Make sure that only a few specific type of url's are
         # considered svn url's
@@ -216,12 +236,21 @@ class TestRecipe(unittest.TestCase):
         self.recipe.options['projectegg'] = 'spameggs'
         self.recipe.create_manage_script([], [])
         self.assert_(os.path.exists(manage))
-        
         # Check that we have 'spameggs' as the project
-        manage = os.path.join(self.bin_dir, 'django')
         self.assert_("djangorecipe.manage.main('spameggs.development')" 
                      in open(manage).read())
 
+    def test_create_wsgi_script_projectegg(self):
+        # When a projectegg is specified, then the egg specified
+        # should get used as the project in the wsgi script.
+        wsgi = os.path.join(self.bin_dir, 'django.wsgi')
+        self.recipe.options['projectegg'] = 'spameggs'
+        self.recipe.make_wsgi_script([])
+        self.assert_(os.path.exists(wsgi))
+        # Check that we have 'spameggs' as the project
+        self.assert_("os.environ['DJANGO_SETTINGS_MODULE']='spameggs.development'"
+                     in open(wsgi).read())
+
     def test_settings_option(self):
         # The settings option can be used to specify the settings file
         # for Django to use. By default it uses `development`.
@@ -286,7 +315,21 @@ class TestRecipe(unittest.TestCase):
         # issued
         self.assertEqual(copytree.call_args, 
                          (('downloads/django-svn', 'parts/django'), {}))
-        
+
+    @mock.patch('shutil', 'copytree')
+    @mock.patch('os.path', 'exists')
+    @mock.patch(Recipe, 'command')
+    def test_install_and_update_svn_version(self, copytree, exists, command):
+        # When an checkout has been done of a svn based installation
+        # is already done the recipe should just update it.
+        exists.return_value = True
+
+        self.recipe.install_svn_version('trunk', 'downloads', 
+                                        'parts/django', False)
+        self.assertEqual(exists.call_args, (('downloads/django-svn',), {}))
+        self.assertEqual(command.call_args, 
+                         (('svn up',), {'cwd': 'downloads/django-svn'}))
+
     @mock.patch(Recipe, 'command')
     def test_install_broken_svn(self, command):
         # When the checkout from svn fails during a svn build the
@@ -314,33 +357,15 @@ class TestRecipe(unittest.TestCase):
         self.assertEqual(copytree.call_args, 
                          (('downloads/django-svn', 'parts/django'), {}))
 
-    @mock.patch('shutil', 'copytree')
     @mock.patch(Recipe, 'command')
-    @mock.patch('os.path', 'exists')
-    def test_update_svn_version(self, copytree, command, path_exists):
-        # If the checkout of a svn release has done before the install
-        # method will just do an update (instead of doing a completely
-        # new installation). To make the recipe believe we already
-        # have a checkout we will mock a function from the os lib.
-        path_exists.return_value = True
-        self.recipe.install_svn_version('trunk', 'downloads', 
-                                        'parts/django', False)
-        self.assertEqual(command.call_args, 
-                         (('svn up downloads/django-svn',), {}))
-        # Like with a normal checkout a copy from the cache to the
-        # destination should have been made
-        self.assertEqual(copytree.call_args, 
-                         (('downloads/django-svn', 'parts/django'), {}))
-
-    @mock.patch('subprocess', 'call')
-    def test_update_svn(self, call_process):
+    def test_update_svn(self, command):
         # When the recipe is asked to do an update and the version is
         # a svn version it just does an update on the parts folder.
         self.recipe.update()
-        self.assertEqual('svn up', call_process.call_args[0][0])
+        self.assertEqual('svn up', command.call_args[0][0])
         # It changes the working directory so that the simple svn up
         # command will work.
-        self.assertEqual(call_process.call_args[1].keys(), ['shell', 'cwd'])
+        self.assertEqual(command.call_args[1].keys(), ['cwd'])
 
     @mock.patch('subprocess', 'call')
     def test_update_with_cache(self, call_process):
@@ -354,15 +379,17 @@ class TestRecipe(unittest.TestCase):
     @mock.patch('os.path', 'exists')
     @mock.patch('urllib', 'urlretrieve')
     @mock.patch('shutil', 'copytree')
-    @mock.patch('os', 'mkdir')
     @mock.patch(ZCRecipeEggScripts, 'working_set')
     @mock.patch('zc.buildout.easy_install', 'scripts')
+    @mock.patch(Recipe, 'install_release')
     def test_clear_existing_django(self, rmtree, path_exists, urlretrieve,
-                                   copytree, mkdir, working_set, scripts):
+                                   copytree, working_set, scripts,
+                                   install_release):
         # When the recipe is executed and Django is already installed
         # within parts it should remove it. We will mock the exists
         # check to make it let the recipe think it has an existing
         # Django install.
+        self.recipe.options['version'] = '1.0'
         path_exists.return_value = True
         working_set.return_value = (None, [])
         self.recipe.install()
@@ -373,8 +400,8 @@ class TestRecipe(unittest.TestCase):
         self.assertEqual(rmtree.call_args[0][0].split('/')[-2:], 
                          ['parts', 'django'])
 
-    @mock.patch('subprocess', 'call')
-    def test_update_pinned_svn_url(self, call):
+    @mock.patch(Recipe, 'command')
+    def test_update_pinned_svn_url(self, command):
         # Make sure that updating a pinned version is updated
         # accordingly. It must not switch to updating beyond it's
         # requested revision.
@@ -384,7 +411,7 @@ class TestRecipe(unittest.TestCase):
 
         self.recipe.options['version'] = 'http://testing/trunk@2531'
         self.recipe.update()
-        self.assertEqual(call.call_args[0], ('svn up -r 2531',))
+        self.assertEqual(command.call_args[0], ('svn up -r 2531',))
 
 
 class ScriptTestCase(unittest.TestCase):
